@@ -3,6 +3,7 @@ from django.contrib import admin
 from django.utils.translation import ugettext_lazy as _
 
 from cmsplugin_blog.admin import M2MPlaceholderAdmin
+from django_libs.admin import MultilingualPublishMixin
 from simple_translation.admin import TranslationAdmin
 
 from .models import Event, EventCategory
@@ -17,9 +18,9 @@ class EventCategoryAdmin(TranslationAdmin):
     title.short_description = _('Title')
 
 
-class EventAdmin(M2MPlaceholderAdmin):
+class EventAdmin(MultilingualPublishMixin, M2MPlaceholderAdmin):
     """Admin class for the ``Event`` model."""
-    list_display = ['title', 'start_date', 'user', 'languages', ]
+    list_display = ['title', 'start_date', 'user', 'languages', 'is_published']
 
     def title(self, obj):
         return obj.get_translation().title
